==> lesserwiki-0.1.0.zip: lesserwiki-0.1.0/config/routes.rb <==
ActionController::Routing::Routes.draw do |map|
  # Add your own custom routes here.
  # The priority is based upon order of creation: first created -> highest priority.
  
  #map.connect '', :controller  => 'view'
  map.connect '', :controller  => 'wiki'
  map.connect ':controller/new/:title', :action => 'new'
  map.connect ':controller/edit/:title', :action => 'edit'
  map.connect ':controller/view/:title', :action => 'view'
  map.connect 'wiki/delete/:title', :controller => 'wiki', :action => 'delete'
  map.connect 'wiki/edit/:title', :controller => 'wiki', :action => 'edit'
  map.connect 'wiki/edit_cancel/:title', :controller => 'wiki', :action => 'edit_cancel'
  map.connect 'wiki/save/:title', :controller => 'wiki', :action => 'save'
  map.connect 'wiki/save', :controller => 'wiki', :action => 'save'  
  map.connect 'wiki/new/:title', :controller => 'wiki', :action => 'new'
  map.connect 'wiki/view_nonexist/:title', :controller => 'wiki', :action => 'view_nonexist'
  map.connect 'wiki/search', :controller => 'wiki', :action => 'search'
  map.connect 'wiki/:title', :controller => 'wiki', :action => 'index'
  map.connect 'wiki/', :controller => 'wiki', :action => 'index'
  map.connect 'ez/:title', :controller => 'ez', :action => 'index'
  map.connect 'ez/', :controller => 'ez', :action => 'index'
  map.connect 'view/:title', :controller => 'view', :action => 'index'
  map.connect 'view/', :controller => 'view', :action => 'index'
  map.connect 'rss/', :controller => 'rss', :action => 'index'
  #map.connect ':title', :controller => 'view', :action => 'index'
  map.connect ':title', :controller => 'wiki', :action => 'index'
  
  # Here's a sample route:
  # map.connect 'products/:id', :controller => 'catalog', :action => 'view'
  # Keep in mind you can assign values other than :controller and :action

  # You can have the root of your site routed by hooking up '' 
  # -- just remember to delete public/index.html.
  # map.connect '', :controller => "welcome"

  # Allow downloading Web Service WSDL as a file with an extension
  # instead of a file named 'wsdl'
  map.connect ':controller/service.wsdl', :action => 'wsdl'

  # Install the default route as the lowest priority.
  map.connect ':controller/:action/:id'
end

==> lesserwiki-0.2.0.zip: lesserwiki-0.2.0/config/routes.rb <==
ActionController::Routing::Routes.draw do |map|
  # Add your own custom routes here.
  # The priority is based upon order of creation: first created -> highest priority.
  
  #map.connect '', :controller  => 'view'
  map.connect '', :controller  => 'wiki'
  map.connect ':controller/new/:title', :action => 'new'
  map.connect ':controller/edit/:title', :action => 'edit'
  map.connect ':controller/view/:title', :action => 'view'
  map.connect 'wiki/delete/:title', :controller => 'wiki', :action => 'delete'
  map.connect 'wiki/edit/:title', :controller => 'wiki', :action => 'edit'
  map.connect 'wiki/edit_cancel/:title', :controller => 'wiki', :action => 'edit_cancel'
  map.connect 'wiki/save/:title', :controller => 'wiki', :action => 'save'
  map.connect 'wiki/save', :controller => 'wiki', :action => 'save'  
  map.connect 'wiki/new/:title', :controller => 'wiki', :action => 'new'
  map.connect 'wiki/view_nonexist/:title', :controller => 'wiki', :action => 'view_nonexist'
  map.connect 'wiki/view_tag/', :controller => 'wiki', :action => 'view_tag'
  map.connect 'wiki/search/:search', :controller => 'wiki', :action => 'search'
  map.connect 'wiki/search', :controller => 'wiki', :action => 'search'
  #map.connect 'wiki/:title', :controller => 'wiki', :action => 'index'
  map.connect 'wiki/', :controller => 'wiki', :action => 'index'
  map.connect 'tiddler/:title', :controller => 'wiki', :action => 'index'
  map.connect 'tag/:name', :controller => 'wiki', :action => 'index'
  map.connect 'search/:search', :controller => 'wiki', :action => 'index'
  map.connect 'ezv/:title', :controller => 'ez_view', :action => 'index'
  map.connect 'ezv/', :controller => 'ez_view', :action => 'index'
  map.connect 'ez/confirm/:title', :controller => 'ez', :action => 'confirm'
  map.connect 'ez/delete/:title', :controller => 'ez', :action => 'delete'
  map.connect 'ez/edit/:title', :controller => 'ez', :action => 'edit'
  map.connect 'ez/edit', :controller => 'ez', :action => 'edit'
  map.connect 'ez/save/:title', :controller => 'ez', :action => 'save'
  map.connect 'ez/save', :controller => 'ez', :action => 'save'  
  map.connect 'ez/new/:title', :controller => 'ez', :action => 'new'
  map.connect 'ez/:title', :controller => 'ez', :action => 'index'
  map.connect 'ez/', :controller => 'ez', :action => 'index'
  map.connect 'view/:title', :controller => 'view', :action => 'index'
  map.connect 'view/', :controller => 'view', :action => 'index'
  map.connect 'rss/', :controller => 'rss', :action => 'index'
  #map.connect ':title', :controller => 'view', :action => 'index'
  map.connect ':title', :controller => 'wiki', :action => 'index'
  
  # Here's a sample route:
  # map.connect 'products/:id', :controller => 'catalog', :action => 'view'
  # Keep in mind you can assign values other than :controller and :action

  # You can have the root of your site routed by hooking up '' 
  # -- just remember to delete public/index.html.
  # map.connect '', :controller => "welcome"

  # Allow downloading Web Service WSDL as a file with an extension
  # instead of a file named 'wsdl'
  map.connect ':controller/service.wsdl', :action => 'wsdl'

  # Install the default route as the lowest priority.
  map.connect ':controller/:action/:id'
end
